/***************************************************************************
 *
 * Test program for "STM32F103RBT6".
 * After program start both LED will fade alternately.
 *
 *************************************************************************/
#define SYSCLK_FREQ_72MHz  72000000

#include "..\LIB\STMF10X\stm32f10x.h"
#include "stm32f10x_conf.h" 
//#include "stm32f10x_it.h"

uint16_t CCR1_Val = 333;
uint16_t CCR2_Val = 249;
uint16_t CCR3_Val = 166;
uint16_t CCR4_Val = 83;
uint16_t PrescalerValue = 0;

void RCC_Configuration(void);
void GPIO_Configuration(void);
void Delay(__IO uint32_t nCount);
void TimersPWMConfiguration(void);
int main(void)
{
  /* System Clocks Configuration */
  RCC_Configuration();

  /* GPIO Configuration */
  GPIO_Configuration();
  
  TimersPWMConfiguration();


  while (1)
  {
	int i = 1;
	for (i=1; i<800; i=i+10)
	{
		TIM_SetCompare3(TIM4, i); //TIM4->CCR3 = i
		TIM_SetCompare4(TIM4, 800-i); //TIM4->CCR4 = i
		TIM_SetCompare1(TIM3, i); //TIM4->CCR4 = i
		Delay(3);
    }
	for (i=800; i>0; i=i-10)
	{
		TIM_SetCompare3(TIM4, i); //TIM4->CCR3 = i
		TIM_SetCompare4(TIM4, 800-i); //TIM4->CCR4 = i	
		TIM_SetCompare1(TIM3, i); //TIM4->CCR4 = i
		Delay(3);
    }
  }
}

void Delay(__IO uint32_t num)
{
	__IO uint32_t index = 0;

	/* default system clock is 72MHz */
	for(index = (72000 * num); index != 0; index--)
	{
	}
}

void RCC_Configuration(void)
{
  /* TIM4 clock enable */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM4, ENABLE);

  /* GPIOA and GPIOB clock enable */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB |
                         RCC_APB2Periph_GPIOC | RCC_APB2Periph_AFIO, ENABLE);
}

void GPIO_Configuration(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;


  /* GPIOA Configuration:TIM4 Channel3 and 4 as alternate function push-pull */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_Init(GPIOB, &GPIO_InitStructure);
  
}

void TimersPWMConfiguration(void)
{
	TIM_TimeBaseInitTypeDef  TIM_TimeBaseStructure;
	TIM_OCInitTypeDef  TIM_OCInitStructure;

   /* Compute the prescaler value */
  //PrescalerValue = (uint16_t) (SystemCoreClock / 24000000) - 1;
  PrescalerValue = (uint16_t) (SystemCoreClock / 72000000) - 1;
  /* Time base configuration */
  TIM_TimeBaseStructure.TIM_Period = 665;
  TIM_TimeBaseStructure.TIM_Prescaler = PrescalerValue;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;

  TIM_TimeBaseInit(TIM4, &TIM_TimeBaseStructure);

  /* PWM1 Mode configuration: common */
  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1;
  TIM_OCInitStructure.TIM_OCPolarity = TIM_OCPolarity_High;

  /* PWM1 Mode configuration: TIM4 Channel3 */
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
  TIM_OCInitStructure.TIM_Pulse = CCR3_Val;
  TIM_OC3Init(TIM4, &TIM_OCInitStructure);
  TIM_OC3PreloadConfig(TIM4, TIM_OCPreload_Enable);
  TIM_ARRPreloadConfig(TIM4, ENABLE);

  /* PWM1 Mode configuration: TIM4 Channel4 */
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
  TIM_OCInitStructure.TIM_Pulse = CCR4_Val;
  TIM_OC4Init(TIM4, &TIM_OCInitStructure);
  TIM_OC4PreloadConfig(TIM4, TIM_OCPreload_Enable);
  TIM_ARRPreloadConfig(TIM4, ENABLE);

  /* TIM4 enable counter */
  TIM_Cmd(TIM4, ENABLE);
  
  
}

/*
====================================================================
Input modes:
--------------------------------------------------------------------
GPIO_Mode_AIN           ;Analog in
GPIO_Mode_IN_FLOATING   ;input floating (less power than IPD or IPU)
GPIO_Mode_IPD           ;input pulled down
GPIO_Mode_IPU           ;input pulled up
====================================================================
Output modes:
--------------------------------------------------------------------
GPIO_Mode_Out_OD        ;output open drain
GPIO_Mode_Out_PP        ;output push-pull
GPIO_Mode_AF_OD         ;alternate function open drain
GPIO_Mode_AF_PP         ;alternate function push pull
====================================================================
*/

